<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:java="http://xml.apache.org/xslt/java"
	xmlns:util="xalan://org.greenstone.gsdl3.util.XSLTUtil"
	xmlns:gslib="http://www.greenstone.org/skinning"
	xmlns:gsf="http://www.greenstone.org/greenstone3/schema/ConfigFormat"
	xmlns:xlink="http://www.w3.org/1999/xlink" 
	extension-element-prefixes="java util"
	exclude-result-prefixes="java util gsf">
  

  <!-- *** -->
  <!-- Document header -->
  <!-- *** -->

  <xsl:template name="soundmanager2-header">

    <!-- soundManager2 API -->
    <gsf:style src="ext/sound-manager2/css/flashblock.css" />  
    <gsf:script src="ext/sound-manager2/script/soundmanager2-nodebug.js"/>

    <!-- The Page player (variant of SoundManger) main script -->
    <gsf:script src="ext/sound-manager2/script/page-player.js"/>
    <gsf:style src="ext/sound-manager2/css/page-player.css" />
        
    <!-- optional: annotations/sub-tracks/notes, and alternate themes -->
    <gsf:style src="ext/sound-manager2/css/optional-annotations.css" />
    <gsf:style src="ext/sound-manager2/css/optional-themes.css" />

    <!-- optional: Metadata UI prototype (not needed unless you want the bottom-most demo bits) -->
    <gsf:script src="ext/sound-manager2/script/optional-page-player-metadata.js"/>
    
    <gsf:style>
      ul.playlist li .comment {font-size:0.65em;opacity:0.5}
    </gsf:style>
    
    <!-- Customization of page-player for this collection -->

    <gsf:script>

      soundManager.flashVersion = 9;
      soundManager.preferFlash = true;        /* for visualization effects */
      soundManager.useHighPerformance = true; /* keep flash on screen, boost performance */
      soundManager.wmode = "transparent";     /* transparent SWF, if possible */
      soundManager.useFastPolling = true;     /* increased JS callback frequency */
      soundManager.url = "ext/sound-manager2/swf/";

      /* custom page player configuration */

      var PP_CONFIG = {
        autoStart:       false,  /* begin playing first sound when page loads */
	playNext:        false,  /* stop after one sound, or play through list until end */
	useThrottling:   false,  /* try to rate-limit potentially-expensive calls (eg. dragging position around) */
	usePeakData:     true,   /* [Flash 9 only] whether or not to show peak data (left/right channel values) - nor noticable on CPU */
	useWaveformData: false,  /* [Flash 9 only] show raw waveform data - WARNING: LIKELY VERY CPU-HEAVY */
	useEQData:       false,  /* [Flash 9 only] show EQ (frequency spectrum) data */
	useFavIcon:      false,  /* try to apply peakData to address bar (Firefox + Opera) - performance note: appears to make Firefox 3 do some temporary, heavy disk access/swapping/garbage collection at first(?) - may be too heavy on CPU */
	useMovieStar:    true    /* Flash 9.0r115+ only: Support for a subset of MPEG4 formats. */
      }
    </gsf:script>
  </xsl:template>


  <!-- CAA = Content Analysis Algorithm -->
  <xsl:variable name="cgiargCAAlgorithm">
    <xsl:choose>
      <xsl:when test="/page/pageRequest/paramList/param[@name='p.caAlgorithm']/@value != ''"><xsl:value-of select="/page/pageRequest/paramList/param[@name='p.caAlgorithm']/@value"/></xsl:when>
      <xsl:otherwise>1</xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <!-- *** -->
  <!-- The Javascript DSP files for computing chroma features in the browser -->
  <!-- *** -->

  <xsl:template name="javascript-dsp-header">
    <gsf:script src="ext/js-dsp/dsp-custom.js"/>
    <gsf:script src="ext/js-dsp/dsp.js"/>
    <gsf:script src="ext/js-dsp/chroma-transform.js"/>
    <gsf:script src="ext/js-dsp/frequency-plotter.js"/>
    <gsf:script src="ext/js-dsp/frequency-player.js"/>


    <gsf:script src="ext/js-dsp/component/crockford-inheritance.js"/>
    <gsf:script src="ext/js-dsp/component/workflow-core.js"/>
    <gsf:script src="ext/js-dsp/component/audio-mixer.js"/>
    <gsf:script src="ext/js-dsp/component/wf-freq-spectrum.js"/>
    <gsf:script src="ext/js-dsp/component/wf-filter-bank.js"/>
    <gsf:script src="ext/js-dsp/component/wf-chroma-transform.js"/>
    <gsf:script src="ext/js-dsp/component/active-workflow.js"/>

  </xsl:template>

  <xsl:template name="processingPopup">
    <div>
      <style type="text/css">	
	#processing { 
	  width: 100%; 
	  height: 100%; 
	  position: absolute; 
	  z-index: 10000; 
	  left: 0px; 
	  top: 0px; 
	  background-color: rgba(255,255,255,0.75); 
	  opacity: 1; 
	  display: none;
	}

	#processingMessage { 
	  position: absolute;
	  padding: 10px;
	  border-radius: 10px; 
	  margin-left: 50%; 
	  width: 380px; 
	  height: 105px; 
	  left: -250px; top: 200px; 
	  background-color: rgba(255,255,255,1);
	  box-shadow: 0px 0px 30px rgba(0,0,0,0.8); 
	}

	#processingMessage p { 
	  font-size: 18px; 
	  text-align: center; 
	  font-family: 
	  sans-serif; 
	  font-weight: bold; 
	  color: #666; 
	}
      </style>
      
      <div id="processing">
	<div id="processingMessage">
	  <h2 id="processingTitle" class="ui-state-default ui-corner-all" style="padding: 8px; font-size: 110%; width: auto;">
	    Heading
	  </h2>
	  <p id="processingText">text</p>
	</div>
      </div>
    </div>

  </xsl:template>

  <!-- *** -->
  <!-- * Discovery -->
  <!-- *** -->

  <xsl:template name="discovery-block">
    
    <div id="fingerprint-turnstyle">

      <div style="background-image: none; background-color: rgb(80%,80%,20%);">
	Discovery: <xsl:call-template name="choose-title"/>
      </div>

      <div class="documenttext" style="display: none;">
	<xsl:call-template name="fingerprintMetadataBlock" />
      </div>

    </div>

    <script>
      <xsl:text disable-output-escaping="yes">
	$(function(){
	transformToTurnstyleBlock("fingerprint");
	});
      </xsl:text>
    </script>
    
  </xsl:template>



  <xsl:template name="fingerprintMetadataBlock">
    
    <xsl:variable name="httpCollection"><xsl:value-of select="/page/pageResponse/collection/metadataList/metadata[@name='httpPath']"/></xsl:variable>
    <xsl:variable name="assocFilePath"><gsf:metadata name="assocfilepath" select="root"/></xsl:variable>


    <xsl:variable name="musicbrainzsongid">
      <gsf:metadata name="dc.Identifier.musicbrainzsongid"/>
    </xsl:variable>

    <xsl:variable name="musicbrainzalbumid">
      <gsf:metadata name="dc.Source.musicbrainzalbumid"/>
    </xsl:variable>

    <xsl:variable name="musicbrainzartistid">
      <gsf:metadata name="dc.Creator.musicbrainzartistid"/>
    </xsl:variable>
    
    <xsl:variable name="lastfmtrackurl">
      <gsf:metadata name="dc.Identifier.lastfmtrackurl"/>
    </xsl:variable>

    <xsl:variable name="echonestsongid">
      <gsf:metadata name="dc.Identifier.echonestsongid"/>
    </xsl:variable>
    
      <table class="metadata-stripes">
	<tbody>
	  <tr>
	    <td>
	      Title
	    </td>
	    <td>
	      <gsf:metadata name="dc.Title"/>
	    </td>
	  </tr>
	  
	  <tr>
	    <td>Album Title</td>
	    <td><gsf:metadata name="dc.Title.albumtitle"/></td>
	  </tr>
	  
	  <tr>
	    <td>Artist</td>
	    <td><gsf:metadata name="dc.Creator"/></td>
	  </tr>
	  
	  <tr valign="top">
	    <td>Artist Summary</td>
	    <td>
	      <i>
		<gsf:script>
		  var summary = gs.documentMetadata["LastFM_LastFMArtistWikiSummary"];
		  
		  document.write(summary.replace("\n","&lt;br /&gt;"));

		</gsf:script>
	      </i>
	    </td>
	  </tr>
	  
<!--
dc.Identifier.echonestsongid
dc.Identifier.echonestartistid

dc.Identifier.lastfmtrackurl
dc.Identifier.lastfmalbumurl
dc.Identifier.lastfmartisturl

//dc.Identifier
dc.Identifier.musicbrainzalbumid
dc.Identifier.musicbrainzartistid
dc.Identifier.musicbrainzsongid
dc.Identifier.playmeartistid

-->

	  <tr>
	    <td colspan="2">

	      <xsl:for-each select="/page/pageResponse/document/metadataList/metadata[@name = 'dc.Relation.artistrelatedimage']">
		<xsl:if test="position() &lt;= 6">
		  <a target="_blank">
		    <xsl:attribute name='href'>
		      <xsl:value-of disable-output-escaping="yes" select="."/>
		    </xsl:attribute>
		    
		    <img width="150">
		      <xsl:attribute name='src'>
			<xsl:value-of disable-output-escaping="yes" select="."/>
		      </xsl:attribute>
		    </img>
		  </a>
		</xsl:if>
	      </xsl:for-each>
	    </td>
	  </tr>

	  <tr>
	    <td>Linked Data</td>
	    <td>
	      <!--
		  <gsf:metadata name="dc.Identifier"/><br />
	      -->

	      <table style="width: 100%;">
		<tr>
		  <td style="width: 200px;">
		    MusicBrainz song id: 
		  </td>
		  <td>
		    <a href="http://dbtune.org/musicbrainz/resource/track/{$musicbrainzsongid}" target="#musicbrainz" class="external">
		      <xsl:copy-of select="$musicbrainzsongid"/>
		    </a>
		  </td>
		</tr>

		<tr>
		  <td>
		    MusicBrainz album id: 
		  </td>
		  <td>
		    <a href="http://dbtune.org/musicbrainz/resource/record/{$musicbrainzalbumid}" target="#musicbrainz" class="external">
		      <xsl:copy-of select="$musicbrainzalbumid"/>
		    </a>
		  </td>
		</tr>

		<tr>
		  <td>
		    MusicBrainz artist id: 
		  </td>
		  <td>
		    <a href="http://dbtune.org/musicbrainz/page/artist/{$musicbrainzartistid}" target="#musicbrainz" class="external">
		      <xsl:copy-of select="$musicbrainzartistid"/>
		    </a>
		  </td>
		</tr>
		<tr>
		  <td>
		    EchoNest song id:
		  </td>
		  <td>
		    <a href="http://developer.echonest.com/api/v4/song/profile?api_key=8WNR9XTGCODO9G4YG&amp;format=xml&amp;id={$echonestsongid}" target="#echonestsongid" class="external">



		      <xsl:copy-of select="$echonestsongid"/>
		    </a>
		  </td>
		</tr>
		<tr>
		  <td colspan="2">	      
		    <i>
		      <a href="{$lastfmtrackurl}" target="#lastfm" class="external">
			<xsl:copy-of select="$lastfmtrackurl"/>
		      </a>
		    </i>
		  </td>
		</tr>
	      </table>

	    </td>
	  </tr>
	  

	</tbody>
      </table>
  </xsl:template>



  <!-- *** -->
  <!-- * Audio Player -->
  <!-- *** -->

  <xsl:template name="js-mad-header">

        <gsf:script src="ext/js-mad/script/mad.js"/>
        <gsf:script src="ext/js-mad/script/rq_table.js"/>
        <gsf:script src="ext/js-mad/script/imdct_s.js"/>
        <gsf:script src="ext/js-mad/script/huffman.js"/>
        <gsf:script src="ext/js-mad/script/bit.js"/>
        <gsf:script src="ext/js-mad/script/stream.js"/>
        <gsf:script src="ext/js-mad/script/layer3.js"/>
        <gsf:script src="ext/js-mad/script/frame.js"/>
        <gsf:script src="ext/js-mad/script/synth.js"/>
       
        <gsf:script src="ext/js-mad/script/arraybuffer/bytestream.js"/>
        <gsf:script src="ext/js-mad/script/arraybuffer/filestream.js"/>
        <gsf:script src="ext/js-mad/script/arraybuffer/substream.js"/>
        <gsf:script src="ext/js-mad/script/arraybuffer/arraystream.js"/>
        <gsf:script src="ext/js-mad/script/arraybuffer/ajaxstream.js"/>

        <gsf:script src="ext/js-mad/script/binarystring/bytestream.js"/>
        <gsf:script src="ext/js-mad/script/binarystring/filestream.js"/>
        <gsf:script src="ext/js-mad/script/binarystring/substream.js"/>
        <gsf:script src="ext/js-mad/script/binarystring/stringstream.js"/>
        <gsf:script src="ext/js-mad/script/binarystring/ajaxstream.js"/>

        <gsf:script src="ext/js-mad/script/id3v22stream.js"/>
        <gsf:script src="ext/js-mad/script/id3v23stream.js"/>
        <gsf:script src="ext/js-mad/script/mp3file.js"/>
        
<!--
        <gsf:script src="ext/js-mad/script/player.js"/>
-->

        <gsf:script src="ext/js-mad/script/sink.min.js"/>

<!--
        <gsf:script src="ext/js-mad/script/require.js"/>
-->
<!--
        <gsf:script src="ext/js-mad/script/sink-light.js"/>
-->

        <gsf:script src="ext/js-mad/script/browser-detect.js"/>
        <gsf:script src="ext/js-mad/script/main-jsmad.js"/>

  </xsl:template>



  <xsl:template name="audio-icon-cache">
    <div style="display:none;">
      <!-- pre-load various play/pause images to help with speed of interface update -->
      <img src="ext/diy-audio-player/images/play32Highlight.png" />
      <img src="ext/diy-audio-player/images/pause32.png" />
      <img src="ext/diy-audio-player/images/pause32Highlight.png" />
      <img src="ext/diy-audio-player/images/play20Highlight.png" />
      <img src="ext/diy-audio-player/images/stop32.png" />
      <img src="ext/diy-audio-player/images/stop32Highlight.png" />
      <img src="ext/diy-audio-player/images/search20Highlight.png" />	
    </div>
  </xsl:template>


  <!-- *** -->
  <!-- * Workflow control -->
  <!-- *** -->

  <xsl:template name="workflow-block">
    <xsl:variable name="httpCollection">
      <xsl:value-of select="/page/pageResponse/collection/metadataList/metadata[@name='httpPath']"/>
    </xsl:variable>

    <div id="workflow-turnstyle">

      <div style="background-image: none; background-color: rgb(80%,80%,20%);">
	Workflow
      </div>

      <div class="documenttext hide" style="color: white; background-color: rgb(40%,40%,20%); padding: 8px;">
	
<!--
	<form style="padding-left: 8px;">
	  <span class="vis-heading">Input Selection:</span>
	  <input type="radio" name="inputSelection" onclick="setInputSelectionMode(this)" value="left"/>Left only
	  <input type="radio" name="inputSelection" onclick="setInputSelectionMode(this)" value="right"/>Right only
	  <input type="radio" name="inputSelection" onclick="setInputSelectionMode(this)" value="diff"/>Average
	  <input type="radio" name="inputSelection" onclick="setInputSelectionMode(this)" value="mix" checked="checked"/>Difference
	</form>
	<hr/>
-->

	<form style="padding-left: 8px; height: 48px;">
	  <span class="vis-heading" style="padding-right: 10px" >Meandre Workflow:</span>

	  <select id="meandre-workflow-pos" onChange="loadSelectedWorkflow(this)" style="font-size: 90%; padding 8px;">
	    <option value="0" selected="selected">Chromagram</option>
	    <option value="1" >Dynamic Javascript Mixer</option>
	  </select>

	  <div style="float: right;" id="meandre-buttons">
	 
	    <button type="button" id="meandre-run-button"  
		    onclick="selectedMeandreWorkflow.runThisMeandreFlow(this)">
	      <img id="meandre-run-button" src="ext/diy-audio-player/images/play32.png" 
		   width="32"
		   height="32"  
		   XXonmouseover="playHighlightOn(this)"
		   XXonmouseout="playHighlightOff(this)"
		   XXonclick="runThisMeandreFlow(this)"
		   style="vertical-align: middle;"/>
	      Run
	    </button>

	    <button type="button" id="meandre-stop-button" onclick="selectedMeandreWorkflow.stopThisMeandreFlow(this)" disabled="disabled">
	      <img id="meandre-stop-button" src="ext/diy-audio-player/images/stop32.png" 
		   width="32"
		   height="32"  
		   XXonmouseover="stopHighlightOn(this)"
		   XXonmouseout="stopHighlightOff(this)"
		   XXonclick="stopThisMeandreFlow(this)"
		   style="vertical-align: middle;"/>
	      Stop
	    </button>

<!--
	    <button type="button" id="meandre-run-button" onclick="runThisMeandreFlow(this)" >Run</button>
	    <button type="button" id="meandre-stop-button" onclick="stopThisMeandreFlow(this)" disabled="disabled">Stop</button>
-->

	  </div>

	</form>

	<style>
	  #meandre-buttons button:hover:enabled {
	    background-color: #CCCC33;
	    color: #FFFFFF;
	  }
	</style>
	  

	<div style="position: relative;">
	  <iframe id="workbenchFrame" 
		  style="width: 100%; height: 400px;" >
	    If you see this, then your browser does not support the iframe element.
	  </iframe>

	</div>

	<gsf:script src="{$httpCollection}/script2/meandre-workflow/chromagram.js"/>
	<gsf:script src="{$httpCollection}/script2/meandre-workflow/js-dynamic-mix.js"/>
	
	<gsf:script>
	  var chromagramMeandreWorkflow = new ChromagramMeandreWorkflow();
	  var jsDynamicMixMeandreWorkflow = new JSDynamicMixMeandreWorkflow();

	  var meandreWorkflows = [ chromagramMeandreWorkflow, jsDynamicMixMeandreWorkflow ];

	  var selectedMeandreWorkflowPos =$('#meandre-workflow-pos option:selected').val();
	  var selectedMeandreWorkflow = meandreWorkflows[selectedMeandreWorkflowPos];

	  selectedMeandreWorkflow.meandreController.loadWorkbench( "workbenchFrame",selectedMeandreWorkflowPos);
	  
	  function loadSelectedWorkflow(elem) { 	       
	      selectedMeandreWorkflowPos = elem.value;
	      selectedMeandreWorkflow = meandreWorkflows[selectedMeandreWorkflowPos];

	    if (selectedMeandreWorkflowPos==1) {
	      $('#jsdynamic-turnstyle').show();
	    }
	    else {
	      $('#jsdynamic-turnstyle').hide();
	    }

	    console.info("Loading in new Meandre workbench flow (pos=" + selectedMeandreWorkflowPos+ ")");		
	    selectedMeandreWorkflow.meandreController.loadWorkbench("workbenchFrame",selectedMeandreWorkflowPos);

	  }
	</gsf:script>
	



	<div id="jsdynamic-turnstyle" style="display:none">
	  
	  <div style="background-image: none; background-color: rgb(80%,80%,20%);">
	    Dynamic Javascript Meandre Component
	  </div>

	  <div class="documenttext hide" style="color: white; background-color: rgb(40%,40%,20%); padding: 8px;">

	    <textarea id="js-dynamic-code" style="width:100%; height: 520px; font-size: 60%">
	      <xsl:text disable-output-escaping="yes">


var arrayBinding = new JavaImporter(java.lang.reflect.Array);

var JSDynamicComponent = function() {
  this.frameCount = 0;
}

JSDynamicComponent.prototype.executeCallBack = function(cc) {

  with(arrayBinding) {

    if ((this.frameCount % 1000)==0) {
      print("JSDynamicComponent: " + this.frameCount + "\n");
    }

    var inputObject = cc.getDataComponentFromInput("input");
    var rawInput1DArray = inputObject;

    var rawOutput1DArray = Array.newInstance(java.lang.Double.TYPE, rawInput1DArray.length);

    for (var i=1; i&lt;rawOutput1DArray.length; i++) {
      var diff = Array.getDouble(rawInput1DArray,i) - Array.getDouble(rawInput1DArray, i-1);
      Array.setDouble(rawOutput1DArray,i,diff);
    }

    cc.pushDataComponentToOutput("output", rawOutput1DArray);

    this.frameCount++;
  }

}

var jsDynamicComponent = new JSDynamicComponent();

	      </xsl:text>
	    </textarea>
	  </div> <!-- end of Dynamic JS turnstyle block -->
	</div>

      </div>

    </div>

    <script>
      <xsl:text disable-output-escaping="yes">
	$(function(){
	    transformToTurnstyleBlock("workflow");
	    transformToTurnstyleBlock("jsdynamic");
	});	
      </xsl:text>
    </script>
  </xsl:template>


  <!-- *** -->
  <!-- * Structured audio player -->
  <!-- *** -->
 
  <xsl:template name="structuredAudioPlayerBlock">

    <gsf:script src="ext/diy-audio-player/script/structured-audio-play.js"/>
    
    <div style="background-color: rgb(40%,40%,20%)">
      <svg xmlns="http://www.w3.org/2000/svg" 
           xmlns:xlink="http://www.w3.org/1999/xlink" 
	   version="1.1"
           id="svgGroundTruthSegments" 
	   width="100%" height="24"
           onLoadXX="svgGTStructuredInit()">
      </svg>
    </div>
    
    <div style="background-color: rgb(40%,40%,20%)">
      <svg xmlns="http://www.w3.org/2000/svg" 
           xmlns:xlink="http://www.w3.org/1999/xlink" 
	   version="1.1"
           id="svgContentAnalysisSegments" 
	   width="100%" height="24"
           onLoadXX="svgCAStructuredInit({$cgiargCAAlgorithm})">
      </svg>
    </div>
  </xsl:template>
  
  <xsl:template name="visualization-mode-block">
    
    <div class="documenttext" style="color: white; background-color: rgb(40%,40%,20%); padding-top: 4px;">

      <span class="vis-heading">Max Values:</span>
      <div style="padding-left: 8px">
	<style>
	  span.mv-fixed { display: inline-block; width: 30pt; }
	</style>
	<table width="100%">
	  <tr>
	    <td><span class="mv-fixed" id="freqSpectrumMax"     >0.000</span>(Freq Spectrum)       </td>
	    <td><span class="mv-fixed" id="freqPowerSpectrumMax">0.000</span>(Freq Power Spectrum) </td>
	    <td><span class="mv-fixed" id="filterBankMax"       >0.000</span>(Filter Bank)         </td>
	    <td><span class="mv-fixed" id="chromaFeaturesMax"   >0.000</span>(Chroma Features)     </td>
	  </tr>
	</table>
      </div>
      <hr/>
  
      <form style="padding-left: 8px; padding-right: 8px; padding-bottom: 0px;">
	<div style="float: left;">
	  <span class="vis-heading">Visualization:</span>
<!--
	<input type="radio" name="visualization" onclick="setTransformMode(this)" value="freqSpectrum" />Frequency Spectrum 
	<input type="radio" name="visualization" onclick="setTransformMode(this)" value="freqPowerSpectrum"/>Frequency Power Spectrum
-->
	
	  <input type="radio" name="visualization" onclick="setTransformMode(this)" value="filterBank"/>Filter Bank 
	  <input type="radio" name="visualization" onclick="setTransformMode(this)" value="chromaFeatures" checked="checked"/>Chroma Features
	</div>

	<div style="float: left; padding-left: 140px;">
	  <span class="vis-heading">Colour Mapping:</span>
	  <input type="radio" name="colorMapping" onclick="setColorMappingMode(this)" value="rgb"/>RGB Intensity
	  <input type="radio" name="colorMapping" onclick="setColorMappingMode(this)" value="hsl" checked="checked"/>HSL Heat
	</div>
      </form>
      
      <div style="clear: both; padding-top: 4px; padding-bottom: 4px;"><hr/></div>

<!--
      <form style="padding-left: 8px;">
	<span class="vis-heading">Colour Mapping:</span>
	<input type="radio" name="colorMapping" onclick="setColorMappingMode(this)" value="rgb"/>RGB Intensity
	<input type="radio" name="colorMapping" onclick="setColorMappingMode(this)" value="hsl" checked="checked"/>HSL Heat Map
      </form>
      <hr/>
-->



	<form style="padding-left: 8px; padding-bottom: 0px;">
	  <div style="float: left;">
	    <input type="checkbox" name="similarityMatrix" onclick="plotSimilarityMatrixWhenPaused(this)"/>Show Similarity Matrix
	  </div>
	  <div style="float: left; padding-left: 140px;">
	    <span class="vis-heading">Accelerated  Processing:</span>
	    <input type="checkbox" name="acceleratedProcessingInput" onclick="acceleratedProcessingCheckbox(this)"/>&gt; realtime
	    <span id="accProcStatus"></span>
	  </div>

	</form>
	<div style="clear: both; padding-top: 4px; padding-bottom: 4px;"><hr/></div>

	<hr/>

    </div>
    
    <xsl:call-template name="graphic-equalizers"/>
  </xsl:template>


  <xsl:template name="graphic-equalizers">


    <gsf:style >
      .control {
        padding: 5px;
        border: 1px solid #CCC;
        background-color: #EEE;
        float: left;
        margin-right: 5px;

      }

      .inner-control {
        background-color: #DDD;
      }

      .control div {
	max-width: 400px;
      }

      .control table td {
        padding: 5px;
        width: 25px;
        color: #999;
        font-size: 12px;
      }
      .control h3 {
        margin: 0;
        padding:0;
        font-size: 12px;
        margin-bottom: 10px;
      }
      .control #debug {
        border: 1px inset #ccc;
        background-color: #FFF;
        font-size: 12px;
        width: 300px;
        padding: 10px;
      }
      .slider {
        margin-bottom: 16px;
        width: 8px;
      }
/*
      .geq-bar {
        width: 34px;
      }
*/

/*
      .ui-button {
        font-size: xx-small;
      }
*/
      .ui-slider .ui-slider-handle {
        width: 8px;
        margin-left: 3px;
      }
    </gsf:style>



   <gsf:script>
      <![CDATA[

        var grapheqL;
        var grapheqR;

      $(function() {
        var geqSampleRate = 44100;
        console.log("*** hardwiring Graphic Equalizer sampleRate to be: " + geqSampleRate);

        grapheqL = new GraphicalEq(geqSampleRate);
        grapheqR = new GraphicalEq(geqSampleRate);
        grapheqL.recalculateFilters();
        grapheqR.recalculateFilters();

        var minPropL = { orientation: 'vertical', range: 'min', min: 10, max: 22000, step: 1, value: 40, 
	                 slide: function() { changeMinFreq(grapheqL,"L")} };
        var minPropR = { orientation: 'vertical', range: 'min', min: 10, max: 22000, step: 1, value: 40, 
	                 slide: function() { changeMinFreq(grapheqR,"R")} };

	var maxPropL = { orientation: 'vertical', range: 'min', min: 10, max: 22000, step: 1, value: 16000, 
	                 slide: function() { changeMaxFreq(grapheqL,"L") } };
	var maxPropR = { orientation: 'vertical', range: 'min', min: 10, max: 22000, step: 1, value: 16000, 
	                 slide: function() { changeMaxFreq(grapheqR,"R") } };

        var bpoPropL = { orientation: 'vertical', range: 'min', min: 0.1, max: 2, step: 0.1, value: 1, 
	                 slide: function() { changeBandsPerOctave(grapheqL,"L")} };
        var bpoPropR = { orientation: 'vertical', range: 'min', min: 0.1, max: 2, step: 0.1, value: 1, 
	                 slide: function() { changeBandsPerOctave(grapheqR,"R")} };

        $('#minFreqL').slider(minPropL);
        $('#maxFreqL').slider(maxPropL);
        $('#minFreqR').slider(minPropR);
        $('#maxFreqR').slider(maxPropR);

        $('#bandsPerOctaveL').slider(bpoPropL);
        $('#bandsPerOctaveR').slider(bpoPropR);

	//$('#input').attr('volume', 0);

	createSliders(grapheqL,"L");
	createSliders(grapheqR,"R");
      });



      var changeMinFreq = function(grapheq,side) {
         grapheq.setMinimumFrequency($('#minFreq'+side).slider('option', 'value'));
         //plotCoeffs();
	 createSliders(grapheq,side);
      }

      var changeMaxFreq = function(grapheq,side) {
         grapheq.setMaximumFrequency($('#maxFreq'+side).slider('option', 'value'));
         //plotCoeffs();
	 createSliders(grapheq,side);
      }

      var changeBandsPerOctave = function(grapheq,side) {
         grapheq.setBandsPerOctave($('#bandsPerOctave'+side).slider('option', 'value'));
         //plotCoeffs();
	 createSliders(grapheq,side);
      }

	function positionGrapheqControl(grapheq,side) {

	    var numSliders = grapheq.filters.length;
            var offset = (35 * numSliders) + 12;
	    if (side == "L") {
	        $('#grapheqControlL').css("left","-" + offset + "px");
	    }
	    else if (side == "R") {
	        offset += 5; // fudge factor
	        $('#grapheqControlR').css("right","-" + offset + "px");
	    }
	    else {
	        console.error("positionGrapheqControl(): unrecognized side '" + side + "'");
	    }
	}

      var createSliders = function(grapheq,side) {
	$('#bandSliders'+side).empty();
	positionGrapheqControl(grapheq,side);
	for (var i=0; i<grapheq.filters.length; i++) {
	
	  var freq = grapheq.filters[i].f0;
	  var units = "Hz";
	  if (freq>=1000000) {
	    freq = (freq/1000000).toFixed(2);
	    units = " MHz";
	  }
	  else if (freq>=1000) {
	    freq = (freq/1000).toFixed(2);
	    units = " KHz";
	  }
	  else if (freq>=100) {
	    freq = freq.toFixed(0);
	  }
	  else {
	    freq = freq.toFixed(0);
	    freq = "&nbsp;" + freq;
	  }

	  $('#bandSliders'+side).append('<td class="geq-bar"><div id="band'+side+'_'+i+'" class="slider"></div>'
	      +freq + ' ' + units + '</td>');

	  $('#band'+side+'_'+i).slider({ orientation: 'vertical', range: 'min', min: -10, max: 3, step: 0.1, value: 0, 
	                                 slide: function(event,ui) { changeBandGain(event,ui,grapheq)} });
	}
      }
      
      var changeBandGain = function(event, ui, grapheq) {
	grapheq.setBandGain(ui.handle.parentNode.id.split("_")[1], ui.value);
        //plotCoeffs();
      }
/*
      var plotCoeffs = function() {
	freqz = new Float32Array(grapheq.freqzs[0].length);

	for (var i=0; i<freqz.length; i++) {
	  for (var j=0; j<grapheq.freqzs.length; j++) {
	    freqz[i] += grapheq.freqzs[j][i];
	  }
	}
      }
*/

/*
      function audioWritten(event) {
        signal = event.mozFrameBuffer;

        // Apply the filter to the signal
        signal = grapheq.processStereo(signal);

        output.mozWriteAudio([]); // flush
        output.mozWriteAudio(signal);
        writeCount++;
      }
*/

        //plotCoeffs();


      ]]>
    </gsf:script>


      <gsf:script>
	function minimizeTurnstyle(suffix) {
	  $('#turnstyleMaximizeButton'+suffix).show();
	  $('#turnstyleMinimizeButton'+suffix).hide();
	  $('#turnstyleContentsArea'+suffix).slideUp('fast');
       }

	function maximizeTurnstyle(suffix) {
	  $('#turnstyleMaximizeButton'+suffix).hide();
	  $('#turnstyleMinimizeButton'+suffix).show();
	  $('#turnstyleContentsArea'+suffix).slideDown('fast');
       }

      </gsf:script>

<!--    
    <div class="control" style="float: left; height: 200px">
-->


    <div id="grapheqControlL" class="control" style="position: absolute; top: 0px; left: -132px; heightXX: 200px">

      <h3 style="float: left;">Graphic Equalizer (left channel)</h3>
      <div style="float: right;">
	<span style="font-size: 75%; padding-right: 5px;">(advanced)</span>
	<a id="turnstyleMinimizeButtonL" style="float: right; font-size: 0.6em; display: none;" href="javascript:minimizeTurnstyle('L');">
	  <img class="icon" style="padding-top:3px;" src="interfaces/{$interface_name}/images/collapse.png"/>
	</a>
	<a id="turnstyleMaximizeButtonL" style="float: right; font-size: 0.6em; display: block;" href="javascript:maximizeTurnstyle('L');">
	  <img style="padding-top:3px;" src="interfaces/{$interface_name}/images/expand.png" class="icon"/>
	</a>
      </div>

      <hr style="clear: both;"/>

      <div id="turnstyleContentsAreaL" style="display: none; float: right;">

	<table class="inner-control" style="margin-bottom: 5px;">
	  <tr>
	    <td><div id="minFreqL" class="slider"><xsl:comment/></div>Min Freq</td>
	    <td><div id="maxFreqL" class="slider"><xsl:comment/></div>Max Freq</td>
	    <td><div id="bandsPerOctaveL" class="slider"><xsl:comment/></div>Bands/ Octave</td>
	  </tr>
	</table>
      </div>

      <div style="clear: both; height: 0px;"><xsl:comment></xsl:comment></div>
	
      <table class="inner-control"> 
	<tr id="bandSlidersL">
	</tr>
      </table>



    </div>

<!--
    <div class="control" style="float: right; height: 200px">
-->

    <div id="grapheqControlR" class="control" style="position: absolute; top: 0px; right: -330px; heightXX: 200px">
      <h3 style="float: left;">Graphic Equalizer (right channel)</h3>

      <div style="float: right;">
	<span style="font-size: 75%; padding-right: 5px;">(advanced)</span>
	<a id="turnstyleMinimizeButtonR" style="float: right; font-size: 0.6em; display: none;" href="javascript:minimizeTurnstyle('R');">
	  <img class="icon" style="padding-top:3px;" src="interfaces/{$interface_name}/images/collapse.png"/>
	</a>
	<a id="turnstyleMaximizeButtonR" style="float: right; font-size: 0.6em; display: block;" href="javascript:maximizeTurnstyle('R');">
	  <img style="padding-top:3px;" src="interfaces/{$interface_name}/images/expand.png" class="icon"/>
	</a>
      </div>

      <hr style="clear: both;"/>

      <div id="turnstyleContentsAreaR" style="display: none; float: left;">
	<table class="inner-control" style="margin-bottom: 5px;">
	  <tr>
	    <td><div id="minFreqR" class="slider"><xsl:comment/></div>Min Freq</td>
	    <td><div id="maxFreqR" class="slider"><xsl:comment/></div>Max Freq</td>
	    <td><div id="bandsPerOctaveR" class="slider"><xsl:comment/></div>Bands/ Octave</td>
	  </tr>
	</table>
      </div>

      <div style="clear: both; height: 0px;"><xsl:comment></xsl:comment></div>

      <table class="inner-control"> 
	<tr id="bandSlidersR">
	</tr>
      </table>

    </div>
    
  </xsl:template>


  <!-- *** -->
  <!-- * Settings form -->
  <!-- *** -->

  <xsl:template name="settings-form">
    <xsl:param name="cgiargYScaleSimImg"/>

    <xsl:variable name="httpCollection">
      <xsl:value-of select="/page/pageResponse/collection/metadataList/metadata[@name='httpPath']"/>
    </xsl:variable>

<!--
    <gsf:variable-array name="overlayNote2">
      <gsf:metadata multiple="true" name="salami.overlayNote" separator=", "/>
    </gsf:variable-array>

    <span id="overlayNewNotes2" class="ui-state-default ui-corner-top" style="font-size:90%; padding: 3px; cursor:pointer;">
      New Annotation 2
    </span>	  

    <div id="noteOverlay2" style="width: 100%; height: 300px; background-color: #cccccc;">
    </div>

    <gsf:script>
      $(window).load(function(){ 
           var overlayNotes2 = new OverlayNotes("noteOverlay2","salami.overlayNote");
	   $('#overlayNewNotes2').click(function() {overlayNotes2.AddNote() });
       });

    </gsf:script>
-->

    <div style="display: none;"><!-- wrapped div to force display to none -->

    <div id="settings-turnstyle" style="margin: 6px;">
      <div style="background-image: none; background-color: rgb(80%,80%,20%);">
	Audio Content Search
      </div>
      <div class="documenttext" style="display: none;">


      <form id="QueryForm" name="QueryForm" method="get" action="{$library_name}">
	<input type="hidden" name="a" value="q"/>
	<input type="hidden" name="sa"><xsl:attribute name="value"><xsl:value-of select="/page/pageRequest/@subaction"/></xsl:attribute></input>
	<input type="hidden" name="rt" value="rd"/>
	
	<input type="hidden" name="s" value="AudioQuery"/>
	<input type="hidden" name="c" value="{$collName}"/>
	<xsl:if test="not(paramList/param[@name='startPage'])">
	  <input type="hidden" name="startPage" value="1"/>
	</xsl:if>
	<xsl:choose>
	  <xsl:when test="/page/pageRequest/paramList/param[@name = 's1.maxDocs']">
	    <input type="hidden" name="s1.maxDocs">
	      <xsl:attribute name="value">
		<xsl:value-of select="/page/pageRequest/paramList/param[@name = 's1.maxDocs']/@value"/>
	      </xsl:attribute>
	    </input>
	  </xsl:when>
	  <xsl:otherwise>
	    <input type="hidden" name="s1.maxDocs" value="100"/>
	  </xsl:otherwise>
	</xsl:choose>
	<xsl:choose>
	  <xsl:when test="/page/pageRequest/paramList/param[@name = 's1.hitsPerPage']">
	    <input type="hidden" name="s1.hitsPerPage">
	      <xsl:attribute name="value">
		<xsl:value-of select="/page/pageRequest/paramList/param[@name = 's1.hitsPerPage']/@value"/>
	      </xsl:attribute>
	    </input>
	  </xsl:when>
	  <xsl:otherwise>
	    <input type="hidden" name="s1.hitsPerPage" value="20"/>
	  </xsl:otherwise>
	</xsl:choose>
	
	<input type="hidden" name="q">
	  <xsl:attribute name="value"><xsl:value-of select="/page/pageResponse/document/documentNode/@nodeID"/>.dir</xsl:attribute>
	</input>
	
	
	<input type="hidden" name="s1.query">
<!--
	  <xsl:attribute name="value"><xsl:value-of select="/page/pageResponse/document/documentNode/@nodeID"/>.dir</xsl:attribute>
-->
	  <xsl:attribute name="value"><xsl:value-of select="/page/pageResponse/document/@nodeID"/>.dir</xsl:attribute>
	</input>
	
	<input type="hidden" name="s1.offset" value="0" />
	<input type="hidden" name="s1.length" value="200" />
	
	<div style="font-style: italics;">Start new query @ offset
	<span id="mysongCurrentPos">0 secs</span>,
	with excerpt lasting
	
	<input type="text" name="mysongWindowDuration" size="4" value="6" />
	<!--
	    <span id="mysongWindowDuration" class="editable-offset"
	    style="cursor: pointer; border: 1px solid black; padding: 3px; width: 200px; min-width: 200px;">6.0</span> 
	-->
	secs:

	<input type="submit" value="Search" onclick="preSubmit(this.form);" />
	</div>

	
	<ul style="font-size: 80%; margin-top: 8px; font-style: italics;" >
	  <li>Use the <b>Play all of</b> bar to get to the part of the song you are interested in.</li>
	  <li>... the <b>query @ offset</b> value will change accordingly as the song progresses.</li>
	  <li>Click <b>pause</b> (anywhere outside of the time-line) to mark the spot you want to start the new music query.</li>
	  <li>Optionally click on the <b>excerpt lasting</b> value and edit, if you want to change the length of excerpt used in the match.</li>
	  <li>Finally, click the <b>Search</b> button to initiate the new query.</li>
	</ul>
	
      </form>

      <hr/>
      
<!--
      <form id="RescaleForm" name="RescaleForm" method="get" action="{$library_name}">
	<div style="font-style: italics;">
	  Make the scale factor for the y-dimension of the self-similarity
	  image be
	  <input type="text" name="ResizeScale" value="{$cgiargYScaleSimImg}"
	         size="3" /> then 
	  <input type="button" name="ResizeImage" value="Resize Image" 
	         onclick="javascript:rescaleImage()" />
	  
	</div>
      </form>
      
      <hr/>
-->

      <!-- **** currently not displayed -->

      <form id="UpdateCAForm" name="UpdateCAForm" method="get" action="{$library_name}" style="display: none;">
	<div style="font-style: italics;">
	  
	  Show the song structure automatically computed by analyzing
	  the audio data using algorithm 

	  <select id="caaMenu" name="caAlgorithm">
	    <option value="1">BV1</option>
	    <option value="2">BV2</option>
	    <option value="3">GP7</option>
	    <option value="4">MHRAG2</option>
	    <option value="5">MND1</option>
	    <option value="6">WB1</option>

<!--
	    <option value="-1">or hide</option>
-->

	  </select>: 

	  <input type="button" name="Reload" value="Reload" 
	         onclick="updateCAAlgorithm()" />

	</div>
      </form>

	<script>
	  <xsl:text disable-output-escaping="yes"> 
	    if (hasStructuredAudio) {
	      var caaMenu = document.getElementById("caaMenu");
               caaMenu.options[caAlgorithm-1].selected = 1;
	    }
	  </xsl:text>
	</script>
      

      </div>
    </div>
    <script>
      <xsl:text disable-output-escaping="yes">
	$(function(){
	transformToTurnstyleBlock("settings");
	});
      </xsl:text>
    </script>

    </div><!-- wrapped div to force display to none -->

  </xsl:template>


  <!-- *** -->
  <!-- * Computed Data -->
  <!-- *** -->


  <xsl:template name="computed-data">
    <xsl:param name="httpCollection"/>
    <xsl:param name="assocFilePath"/>

    <div id="computed-turnstyle" style="margin: 6px;">
      <div style="background-image: none; background-color: rgb(80%,80%,20%);">
	Computed Data
      </div>

      <div class="documenttext" style="display: none;">
	<table class="metadata-stripes" style="width: 100%">
	  <tbody>
	    <tr>
	      <td>jAudio Features</td><td><a href="{$httpCollection}/index/assoc/{$assocFilePath}/jaudio.xml">download ACE XML feature values file</a></td>
	    </tr>
	    
	    <tr>
	      <td>jSongMiner Metadata</td><td><a href="{$httpCollection}/index/assoc/{$assocFilePath}/jsongminer.xml">download ACE XML classifications file</a></td>
	    </tr>
	    
	  </tbody>
	</table>
      </div>
    </div>

    <gsf:script>
	$(function(){
	  transformToTurnstyleBlock("computed");
	});
    </gsf:script>

  </xsl:template>



  <xsl:template name="original-audio">
    <xsl:param name="httpCollection"/>
    <xsl:param name="assocFilePath"/>
    <xsl:param name="Audio"/>
    <xsl:param name="streamableaudio"/>

    <div id="original-turnstyle" style="margin: 6px;">
      <div style="background-image: none; background-color: rgb(80%,80%,20%);">
	The Original Audio
      </div>

      <div style="display: none;">

	<div>
	  <audio style="width: 100%;" id="original-audio" controls="controls" >
<!--
	    <source src="{$httpCollection}/index/assoc/{$assocFilePath}/doc.ogg" />
-->
	    <source src="{$httpCollection}/index/assoc/{$assocFilePath}/{$streamableaudio}" />
	    <source src="{$httpCollection}/index/assoc/{$assocFilePath}/{$Audio}" />
	  </audio>
	</div>

      </div>
    </div>

    <gsf:script>
	$(function(){
	  transformToTurnstyleBlock("original");
	});
    </gsf:script>



  </xsl:template>


</xsl:stylesheet>
